@@ -70,659 +70,563 @@ function zip_entry_compressionmethod($zip_entry): string|false {}
 class ZipArchive implements Countable
 {
     /**
-     * @var int
      * @cvalue ZIP_CREATE
      */
-    public const CREATE = UNKNOWN;
+    public const int CREATE = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_EXCL
      */
-    public const EXCL = UNKNOWN;
+    public const int EXCL = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_CHECKCONS
      */
-    public const CHECKCONS = UNKNOWN;
+    public const int CHECKCONS = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_OVERWRITE
      */
-    public const OVERWRITE = UNKNOWN;
+    public const int OVERWRITE = UNKNOWN;
 #ifdef ZIP_RDONLY
     /**
-     * @var int
      * @cvalue ZIP_RDONLY
      */
-    public const RDONLY = UNKNOWN;
+    public const int RDONLY = UNKNOWN;
 #endif
 
     /**
-     * @var int
      * @cvalue ZIP_FL_NOCASE
      */
-    public const FL_NOCASE = UNKNOWN;
+    public const int FL_NOCASE = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_FL_NODIR
      */
-    public const FL_NODIR = UNKNOWN;
+    public const int FL_NODIR = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_FL_COMPRESSED
      */
-    public const FL_COMPRESSED = UNKNOWN;
+    public const int FL_COMPRESSED = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_FL_UNCHANGED
      */
-    public const FL_UNCHANGED = UNKNOWN;
+    public const int FL_UNCHANGED = UNKNOWN;
 /* deprecated in libzip 1.10.0 */
 #ifdef ZIP_FL_RECOMPRESS
     /**
-     * @var int
      * @cvalue ZIP_FL_RECOMPRESS
      * @deprecated
      */
-    public const FL_RECOMPRESS = UNKNOWN;
+    public const int FL_RECOMPRESS = UNKNOWN;
 #endif
     /**
-     * @var int
      * @cvalue ZIP_FL_ENCRYPTED
      */
-    public const FL_ENCRYPTED = UNKNOWN;
+    public const int FL_ENCRYPTED = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_FL_OVERWRITE
      */
-    public const FL_OVERWRITE = UNKNOWN;
+    public const int FL_OVERWRITE = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_FL_LOCAL
      */
-    public const FL_LOCAL = UNKNOWN;
+    public const int FL_LOCAL = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_FL_CENTRAL
      */
-    public const FL_CENTRAL = UNKNOWN;
+    public const int FL_CENTRAL = UNKNOWN;
 
     /* Default filename encoding policy. */
 
     /**
-     * @var int
      * @cvalue ZIP_FL_ENC_GUESS
      */
-    public const FL_ENC_GUESS = UNKNOWN;
+    public const int FL_ENC_GUESS = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_FL_ENC_RAW
      */
-    public const FL_ENC_RAW = UNKNOWN;
+    public const int FL_ENC_RAW = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_FL_ENC_STRICT
      */
-    public const FL_ENC_STRICT = UNKNOWN;
+    public const int FL_ENC_STRICT = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_FL_ENC_UTF_8
      */
-    public const FL_ENC_UTF_8 = UNKNOWN;
+    public const int FL_ENC_UTF_8 = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_FL_ENC_CP437
      */
-    public const FL_ENC_CP437 = UNKNOWN;
+    public const int FL_ENC_CP437 = UNKNOWN;
 
     /**
      * Additionnal flags not from libzip
-     * @var int
      * @cvalue ZIP_FL_OPEN_FILE_NOW
      */
-    public const FL_OPEN_FILE_NOW = UNKNOWN;
+    public const int FL_OPEN_FILE_NOW = UNKNOWN;
 
     /**
-     * @var int
      * @cvalue ZIP_CM_DEFAULT
      */
-    public const CM_DEFAULT = UNKNOWN;
+    public const int CM_DEFAULT = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_CM_STORE
      */
-    public const CM_STORE = UNKNOWN;
+    public const int CM_STORE = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_CM_SHRINK
      */
-    public const CM_SHRINK = UNKNOWN;
+    public const int CM_SHRINK = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_CM_REDUCE_1
      */
-    public const CM_REDUCE_1 = UNKNOWN;
+    public const int CM_REDUCE_1 = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_CM_REDUCE_2
      */
-    public const CM_REDUCE_2 = UNKNOWN;
+    public const int CM_REDUCE_2 = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_CM_REDUCE_3
      */
-    public const CM_REDUCE_3 = UNKNOWN;
+    public const int CM_REDUCE_3 = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_CM_REDUCE_4
      */
-    public const CM_REDUCE_4 = UNKNOWN;
+    public const int CM_REDUCE_4 = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_CM_IMPLODE
      */
-    public const CM_IMPLODE = UNKNOWN;
+    public const int CM_IMPLODE = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_CM_DEFLATE
      */
-    public const CM_DEFLATE = UNKNOWN;
+    public const int CM_DEFLATE = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_CM_DEFLATE64
      */
-    public const CM_DEFLATE64 = UNKNOWN;
+    public const int CM_DEFLATE64 = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_CM_PKWARE_IMPLODE
      */
-    public const CM_PKWARE_IMPLODE = UNKNOWN;
+    public const int CM_PKWARE_IMPLODE = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_CM_BZIP2
      */
-    public const CM_BZIP2 = UNKNOWN;
+    public const int CM_BZIP2 = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_CM_LZMA
      */
-    public const CM_LZMA = UNKNOWN;
+    public const int CM_LZMA = UNKNOWN;
 #ifdef ZIP_CM_LZMA2
     /**
-     * @var int
      * @cvalue ZIP_CM_LZMA2
      */
-    public const CM_LZMA2 = UNKNOWN;
+    public const int CM_LZMA2 = UNKNOWN;
 #endif
 
 #ifdef ZIP_CM_ZSTD
     /**
-     * @var int
      * @cvalue ZIP_CM_ZSTD
      */
-    public const CM_ZSTD = UNKNOWN;
+    public const int CM_ZSTD = UNKNOWN;
 #endif
 #ifdef ZIP_CM_XZ
     /**
-     * @var int
      * @cvalue ZIP_CM_XZ
      */
-    public const CM_XZ = UNKNOWN;
+    public const int CM_XZ = UNKNOWN;
 #endif
     /**
-     * @var int
      * @cvalue ZIP_CM_TERSE
      */
-    public const CM_TERSE = UNKNOWN;
+    public const int CM_TERSE = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_CM_LZ77
      */
-    public const CM_LZ77 = UNKNOWN;
+    public const int CM_LZ77 = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_CM_WAVPACK
      */
-    public const CM_WAVPACK = UNKNOWN;
+    public const int CM_WAVPACK = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_CM_PPMD
      */
-    public const CM_PPMD = UNKNOWN;
+    public const int CM_PPMD = UNKNOWN;
 
     /* Error code */
 
     /**
      * N No error
-     * @var int
      * @cvalue ZIP_ER_OK
      */
-    public const ER_OK = UNKNOWN;
+    public const int ER_OK = UNKNOWN;
     /**
      * N Multi-disk zip archives not supported
-     * @var int
      * @cvalue ZIP_ER_MULTIDISK
      */
-    public const ER_MULTIDISK = UNKNOWN;
+    public const int ER_MULTIDISK = UNKNOWN;
     /**
      * S Renaming temporary file failed
-     * @var int
      * @cvalue ZIP_ER_RENAME
      */
-    public const ER_RENAME = UNKNOWN;
+    public const int ER_RENAME = UNKNOWN;
     /**
      * S Closing zip archive failed
-     * @var int
      * @cvalue ZIP_ER_CLOSE
      */
-    public const ER_CLOSE = UNKNOWN;
+    public const int ER_CLOSE = UNKNOWN;
     /**
      * S Seek error
-     * @var int
      * @cvalue ZIP_ER_SEEK
      */
-    public const ER_SEEK = UNKNOWN;
+    public const int ER_SEEK = UNKNOWN;
     /**
      * S Read error
-     * @var int
      * @cvalue ZIP_ER_READ
      */
-    public const ER_READ = UNKNOWN;
+    public const int ER_READ = UNKNOWN;
     /**
      * S Write error
-     * @var int
      * @cvalue ZIP_ER_WRITE
      */
-    public const ER_WRITE = UNKNOWN;
+    public const int ER_WRITE = UNKNOWN;
     /**
      * N CRC error
-     * @var int
      * @cvalue ZIP_ER_CRC
      */
-    public const ER_CRC = UNKNOWN;
+    public const int ER_CRC = UNKNOWN;
     /**
      * N Containing zip archive was closed
-     * @var int
      * @cvalue ZIP_ER_ZIPCLOSED
      */
-    public const ER_ZIPCLOSED = UNKNOWN;
+    public const int ER_ZIPCLOSED = UNKNOWN;
     /**
      * N No such file
-     * @var int
      * @cvalue ZIP_ER_NOENT
      */
-    public const ER_NOENT = UNKNOWN;
+    public const int ER_NOENT = UNKNOWN;
     /**
      * N File already exists
-     * @var int
      * @cvalue ZIP_ER_EXISTS
      */
-    public const ER_EXISTS = UNKNOWN;
+    public const int ER_EXISTS = UNKNOWN;
     /**
      * S Can't open file
-     * @var int
      * @cvalue ZIP_ER_OPEN
      */
-    public const ER_OPEN = UNKNOWN;
+    public const int ER_OPEN = UNKNOWN;
     /**
      * S Failure to create temporary file
-     * @var int
      * @cvalue ZIP_ER_TMPOPEN
      */
-    public const ER_TMPOPEN = UNKNOWN;
+    public const int ER_TMPOPEN = UNKNOWN;
     /**
      * Z Zlib error
-     * @var int
      * @cvalue ZIP_ER_ZLIB
      */
-    public const ER_ZLIB = UNKNOWN;
+    public const int ER_ZLIB = UNKNOWN;
     /**
      * N Malloc failure
-     * @var int
      * @cvalue ZIP_ER_MEMORY
      */
-    public const ER_MEMORY = UNKNOWN;
+    public const int ER_MEMORY = UNKNOWN;
     /**
      * N Entry has been changed
-     * @var int
      * @cvalue ZIP_ER_CHANGED
      */
-    public const ER_CHANGED = UNKNOWN;
+    public const int ER_CHANGED = UNKNOWN;
     /**
      * N Compression method not supported
-     * @var int
      * @cvalue ZIP_ER_COMPNOTSUPP
      */
-    public const ER_COMPNOTSUPP = UNKNOWN;
+    public const int ER_COMPNOTSUPP = UNKNOWN;
     /**
      * N Premature EOF
-     * @var int
      * @cvalue ZIP_ER_EOF
      */
-    public const ER_EOF = UNKNOWN;
+    public const int ER_EOF = UNKNOWN;
     /**
      * N Invalid argument
-     * @var int
      * @cvalue ZIP_ER_INVAL
      */
-    public const ER_INVAL = UNKNOWN;
+    public const int ER_INVAL = UNKNOWN;
     /**
      * N Not a zip archive
-     * @var int
      * @cvalue ZIP_ER_NOZIP
      */
-    public const ER_NOZIP = UNKNOWN;
+    public const int ER_NOZIP = UNKNOWN;
     /**
      * N Internal error
-     * @var int
      * @cvalue ZIP_ER_INTERNAL
      */
-    public const ER_INTERNAL = UNKNOWN;
+    public const int ER_INTERNAL = UNKNOWN;
     /**
      * N Zip archive inconsistent
-     * @var int
      * @cvalue ZIP_ER_INCONS
      */
-    public const ER_INCONS = UNKNOWN;
+    public const int ER_INCONS = UNKNOWN;
     /**
      * S Can't remove file
-     * @var int
      * @cvalue ZIP_ER_REMOVE
      */
-    public const ER_REMOVE = UNKNOWN;
+    public const int ER_REMOVE = UNKNOWN;
     /**
      * N Entry has been deleted
-     * @var int
      * @cvalue ZIP_ER_DELETED
      */
-    public const ER_DELETED = UNKNOWN;
+    public const int ER_DELETED = UNKNOWN;
     /**
      * N Encryption method not supported
-     * @var int
      * @cvalue ZIP_ER_ENCRNOTSUPP
      */
-    public const ER_ENCRNOTSUPP = UNKNOWN;
+    public const int ER_ENCRNOTSUPP = UNKNOWN;
     /**
      * N Read-only archive
-     * @var int
      * @cvalue ZIP_ER_RDONLY
      */
-    public const ER_RDONLY = UNKNOWN;
+    public const int ER_RDONLY = UNKNOWN;
     /**
      * N Entry has been deleted
-     * @var int
      * @cvalue ZIP_ER_NOPASSWD
      */
-    public const ER_NOPASSWD = UNKNOWN;
+    public const int ER_NOPASSWD = UNKNOWN;
     /**
      * N Wrong password provided
-     * @var int
      * @cvalue ZIP_ER_WRONGPASSWD
      */
-    public const ER_WRONGPASSWD = UNKNOWN;
+    public const int ER_WRONGPASSWD = UNKNOWN;
 
     /* since 1.0.0 */
-
 #ifdef ZIP_ER_OPNOTSUPP
     /**
      * N Operation not supported
-     * @var int
      * @cvalue ZIP_ER_OPNOTSUPP
      */
-    public const ER_OPNOTSUPP = UNKNOWN;
+    public const int ER_OPNOTSUPP = UNKNOWN;
 #endif
 #ifdef ZIP_ER_INUSE
     /**
      * N Resource still in use
-     * @var int
      * @cvalue ZIP_ER_INUSE
      */
-    public const ER_INUSE = UNKNOWN;
+    public const int ER_INUSE = UNKNOWN;
 #endif
 #ifdef ZIP_ER_TELL
     /**
      * S Tell error
-     * @var int
      * @cvalue ZIP_ER_TELL
      */
-    public const ER_TELL = UNKNOWN;
+    public const int ER_TELL = UNKNOWN;
 #endif
 
     /* since 1.6.0 */
 #ifdef ZIP_ER_COMPRESSED_DATA
     /**
      * N Compressed data invalid
-     * @var int
      * @cvalue ZIP_ER_COMPRESSED_DATA
      */
-    public const ER_COMPRESSED_DATA = UNKNOWN;
+    public const int ER_COMPRESSED_DATA = UNKNOWN;
 #endif
 #ifdef ZIP_ER_CANCELLED
     /**
      * N Operation cancelled
-     * @var int
      * @cvalue ZIP_ER_CANCELLED
      */
-    public const ER_CANCELLED = UNKNOWN;
+    public const int ER_CANCELLED = UNKNOWN;
 #endif
 
     /* since 1.10.0 */
 #ifdef ZIP_ER_DATA_LENGTH
     /**
      * N Unexpected length of data
-     * @var int
      * @cvalue ZIP_ER_DATA_LENGTH
      */
-    public const ER_DATA_LENGTH = UNKNOWN;
+    public const int ER_DATA_LENGTH = UNKNOWN;
 #endif
 #ifdef ZIP_ER_NOT_ALLOWED
     /**
      * Not allowed in torrentzip
-     * @var int
      * @cvalue ZIP_ER_NOT_ALLOWED
      */
-    public const ER_NOT_ALLOWED = UNKNOWN;
+    public const int ER_NOT_ALLOWED = UNKNOWN;
 #endif
 #ifdef ZIP_AFL_RDONLY
     /**
      * read only -- cannot be cleared
-     * @var int
      * @cvalue ZIP_AFL_RDONLY
      */
-    public const AFL_RDONLY = UNKNOWN;
+    public const int AFL_RDONLY = UNKNOWN;
 #endif
 #ifdef ZIP_AFL_IS_TORRENTZIP
     /**
      * current archive is torrentzipped
-     * @var int
      * @cvalue ZIP_AFL_IS_TORRENTZIP
      */
-    public const AFL_IS_TORRENTZIP = UNKNOWN;
+    public const int AFL_IS_TORRENTZIP = UNKNOWN;
 #endif
 #ifdef ZIP_AFL_WANT_TORRENTZIP
     /**
      * write archive in torrentzip format
-     * @var int
      * @cvalue ZIP_AFL_WANT_TORRENTZIP
      */
-    public const AFL_WANT_TORRENTZIP = UNKNOWN;
+    public const int AFL_WANT_TORRENTZIP = UNKNOWN;
 #endif
 #ifdef ZIP_AFL_CREATE_OR_KEEP_FILE_FOR_EMPTY_ARCHIVE
     /**
      * don't remove file if archive is empty
-     * @var int
      * @cvalue ZIP_AFL_CREATE_OR_KEEP_FILE_FOR_EMPTY_ARCHIVE
      */
-    public const AFL_CREATE_OR_KEEP_FILE_FOR_EMPTY_ARCHIVE = UNKNOWN;
+    public const int AFL_CREATE_OR_KEEP_FILE_FOR_EMPTY_ARCHIVE = UNKNOWN;
 #endif
 
 #ifdef ZIP_OPSYS_DEFAULT
     /**
-     * @var int
      * @cvalue ZIP_OPSYS_DOS
      * @link ziparchive.constants.opsys
      */
-    public const OPSYS_DOS = UNKNOWN;
+    public const int OPSYS_DOS = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_OPSYS_AMIGA
      * @link ziparchive.constants.opsys
      */
-    public const OPSYS_AMIGA = UNKNOWN;
+    public const int OPSYS_AMIGA = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_OPSYS_OPENVMS
      * @link ziparchive.constants.opsys
      */
-    public const OPSYS_OPENVMS = UNKNOWN;
+    public const int OPSYS_OPENVMS = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_OPSYS_UNIX
      * @link ziparchive.constants.opsys
      */
-    public const OPSYS_UNIX = UNKNOWN;
+    public const int OPSYS_UNIX = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_OPSYS_VM_CMS
      * @link ziparchive.constants.opsys
      */
-    public const OPSYS_VM_CMS = UNKNOWN;
+    public const int OPSYS_VM_CMS = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_OPSYS_ATARI_ST
      * @link ziparchive.constants.opsys
      */
-    public const OPSYS_ATARI_ST = UNKNOWN;
+    public const int OPSYS_ATARI_ST = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_OPSYS_OS_2
      * @link ziparchive.constants.opsys
      */
-    public const OPSYS_OS_2 = UNKNOWN;
+    public const int OPSYS_OS_2 = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_OPSYS_MACINTOSH
      * @link ziparchive.constants.opsys
      */
-    public const OPSYS_MACINTOSH = UNKNOWN;
+    public const int OPSYS_MACINTOSH = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_OPSYS_Z_SYSTEM
      * @link ziparchive.constants.opsys
      */
-    public const OPSYS_Z_SYSTEM = UNKNOWN;
+    public const int OPSYS_Z_SYSTEM = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_OPSYS_CPM
      * @link ziparchive.constants.opsys
      */
-    public const OPSYS_CPM = UNKNOWN;
+    public const int OPSYS_CPM = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_OPSYS_WINDOWS_NTFS
      * @link ziparchive.constants.opsys
      */
-    public const OPSYS_WINDOWS_NTFS = UNKNOWN;
+    public const int OPSYS_WINDOWS_NTFS = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_OPSYS_MVS
      * @link ziparchive.constants.opsys
      */
-    public const OPSYS_MVS = UNKNOWN;
+    public const int OPSYS_MVS = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_OPSYS_VSE
      * @link ziparchive.constants.opsys
      */
-    public const OPSYS_VSE = UNKNOWN;
+    public const int OPSYS_VSE = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_OPSYS_ACORN_RISC
      * @link ziparchive.constants.opsys
      */
-    public const OPSYS_ACORN_RISC = UNKNOWN;
+    public const int OPSYS_ACORN_RISC = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_OPSYS_VFAT
      * @link ziparchive.constants.opsys
      */
-    public const OPSYS_VFAT = UNKNOWN;
+    public const int OPSYS_VFAT = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_OPSYS_ALTERNATE_MVS
      * @link ziparchive.constants.opsys
      */
-    public const OPSYS_ALTERNATE_MVS = UNKNOWN;
+    public const int OPSYS_ALTERNATE_MVS = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_OPSYS_BEOS
      * @link ziparchive.constants.opsys
      */
-    public const OPSYS_BEOS = UNKNOWN;
+    public const int OPSYS_BEOS = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_OPSYS_TANDEM
      * @link ziparchive.constants.opsys
      */
-    public const OPSYS_TANDEM = UNKNOWN;
+    public const int OPSYS_TANDEM = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_OPSYS_OS_400
      * @link ziparchive.constants.opsys
      */
-    public const OPSYS_OS_400 = UNKNOWN;
+    public const int OPSYS_OS_400 = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_OPSYS_OS_X
      * @link ziparchive.constants.opsys
      */
-    public const OPSYS_OS_X = UNKNOWN;
+    public const int OPSYS_OS_X = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_OPSYS_DEFAULT
      * @link ziparchive.constants.opsys
      */
-    public const OPSYS_DEFAULT = UNKNOWN;
+    public const int OPSYS_DEFAULT = UNKNOWN;
 #endif
 
     /**
-     * @var int
      * @cvalue ZIP_EM_NONE
      */
-    public const EM_NONE = UNKNOWN;
+    public const int EM_NONE = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_EM_TRAD_PKWARE
      */
-    public const EM_TRAD_PKWARE = UNKNOWN;
+    public const int EM_TRAD_PKWARE = UNKNOWN;
 #ifdef HAVE_ENCRYPTION
     /**
-     * @var int
      * @cvalue ZIP_EM_AES_128
      */
-    public const EM_AES_128 = UNKNOWN;
+    public const int EM_AES_128 = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_EM_AES_192
      */
-    public const EM_AES_192 = UNKNOWN;
+    public const int EM_AES_192 = UNKNOWN;
     /**
-     * @var int
      * @cvalue ZIP_EM_AES_256
      */
-    public const EM_AES_256 = UNKNOWN;
+    public const int EM_AES_256 = UNKNOWN;
 #endif
     /**
-     * @var int
      * @cvalue ZIP_EM_UNKNOWN
      */
-    public const EM_UNKNOWN = UNKNOWN;
+    public const int EM_UNKNOWN = UNKNOWN;
 
     /**
-     * @var string
      * @cvalue LIBZIP_VERSION_STR
      */
-    public const LIBZIP_VERSION = UNKNOWN;
+    public const string LIBZIP_VERSION = UNKNOWN;
+
+    /**
+     * @cvalue ZIP_LENGTH_TO_END
+     */
+    public const int LENGTH_TO_END = UNKNOWN;
+    /* since 1.10.1 */
+#ifdef ZIP_LENGTH_UNCHECKED
+    /**
+     * @cvalue ZIP_LENGTH_UNCHECKED
+     */
+    public const int LENGTH_UNCHECKED = UNKNOWN;
+#endif
 
     /** @readonly */
     public int $lastId;
@@ -763,10 +667,10 @@ class ZipArchive implements Countable
     public function addFromString(string $name, string $content, int $flags = ZipArchive::FL_OVERWRITE): bool {}
 
     /** @tentative-return-type */
-    public function addFile(string $filepath, string $entryname = "", int $start = 0, int $length = 0, int $flags = ZipArchive::FL_OVERWRITE): bool {}
+    public function addFile(string $filepath, string $entryname = "", int $start = 0, int $length = ZipArchive::LENGTH_TO_END, int $flags = ZipArchive::FL_OVERWRITE): bool {}
 
     /** @tentative-return-type */
-    public function replaceFile(string $filepath, int $index, int $start = 0, int $length = 0, int $flags = 0): bool {}
+    public function replaceFile(string $filepath, int $index, int $start = 0, int $length = ZipArchive::LENGTH_TO_END, int $flags = 0): bool {}
 
     /** @tentative-return-type */
     public function addGlob(string $pattern, int $flags = 0, array $options = []): array|false {}
